@@ -455,6 +455,10 @@ def test_projects_overview_hides_create_button(repo: ProjectRepository, tmp_path
     labels = [btn.text for row in markup.inline_keyboard for btn in row]
     assert "➕ 新增项目" not in labels
     assert "🚀 启动全部项目" in labels
+    run_buttons = [label for label in labels if label.startswith("▶️ 启动")]
+    stop_buttons = [label for label in labels if label.startswith("⛔️ 停止")]
+    for label in run_buttons + stop_buttons:
+        assert "(" in label and label.endswith(")"), "运行/停止按钮应展示当前模型"
 
 
 def test_manage_action_sends_inline_menu(repo: ProjectRepository, tmp_path: Path, monkeypatch):
@@ -470,8 +474,12 @@ def test_manage_action_sends_inline_menu(repo: ProjectRepository, tmp_path: Path
     assert callback.message._answers, "应发送管理选项"
     buttons = callback.message._answers[0][1]["reply_markup"].inline_keyboard
     texts = [btn.text for row in buttons for btn in row]
+    callbacks = [btn.callback_data for row in buttons for btn in row]
     assert "📝 编辑" in texts
+    assert "🧠 切换模型" in texts
     assert "🗑 删除" in texts
+    assert "project:switch_prompt:sample" in callbacks
+    assert all(not cb.startswith("project:switch_to") for cb in callbacks)
 
 
 def test_manage_button_handler_builds_keyboard(repo: ProjectRepository, tmp_path: Path, monkeypatch):
@@ -493,6 +501,42 @@ def test_manage_button_handler_builds_keyboard(repo: ProjectRepository, tmp_path
     labels = [btn.text for row in markup.inline_keyboard for btn in row]
     assert "➕ 新增项目" in labels
     assert any(label.startswith("⚙️ 管理") for label in labels)
+    assert "🧠 模型" in labels
+    assert "🔁 全部切换模型" in labels
+    rows = markup.inline_keyboard
+    assert any(row[0].text.startswith("⚙️ 管理") and row[1].text == "🧠 模型" for row in rows if len(row) >= 2), "项目管理列表应同排展示管理与模型按钮"
+
+
+def test_switch_prompt_displays_model_options(repo: ProjectRepository, tmp_path: Path):
+    manager = _build_manager(repo, tmp_path)
+    master.MANAGER = manager
+    master.PROJECT_REPOSITORY = repo
+    manager.state_store.update("sample", model="claudecode", status="stopped")
+    callback_message = DummyMessage()
+    callback = DummyCallback("project:switch_prompt:sample", message=callback_message)
+    _, fsm_state = _build_fsm_state()
+
+    async def _invoke():
+        await master.on_project_action(callback, fsm_state)
+
+    asyncio.run(_invoke())
+    assert callback._answers == [(None, False)]
+    assert callback_message._answers, "应弹出模型选择菜单"
+    reply_markup = callback_message._answers[-1][1]["reply_markup"]
+    model_callbacks = [
+        btn.callback_data
+        for row in reply_markup.inline_keyboard
+        for btn in row
+        if btn.callback_data
+    ]
+    model_texts = [
+        btn.text
+        for row in reply_markup.inline_keyboard
+        for btn in row
+    ]
+    assert any(cb.startswith("project:switch_to:") for cb in model_callbacks), "应包含切换模型回调"
+    assert any(text.startswith("✅ ") for text in model_texts), "当前模型应以 ✅ 标记"
+    assert "project:refresh:*" in model_callbacks, "应提供返回列表按钮"
 
 
 def test_refresh_action_skips_slug_validation(repo: ProjectRepository, tmp_path: Path, monkeypatch):
@@ -512,3 +556,93 @@ def test_refresh_action_skips_slug_validation(repo: ProjectRepository, tmp_path:
     text, kwargs = callback_message._edits[0]
     assert text == "请选择操作："
     assert kwargs["reply_markup"] is not None
+
+
+def test_switch_to_running_project_updates_state(repo: ProjectRepository, tmp_path: Path, monkeypatch):
+    manager = _build_manager(repo, tmp_path)
+    master.MANAGER = manager
+    master.PROJECT_REPOSITORY = repo
+    manager.state_store.update("sample", model="codex", status="running")
+
+    async def stop_worker_override(cfg: master.ProjectConfig, *, update_state: bool = True) -> None:
+        manager.state_store.update(cfg.project_slug, status="stopped")
+
+    async def run_worker_override(cfg: master.ProjectConfig, model: str | None = None) -> str:
+        chosen = model or cfg.default_model
+        manager.state_store.update(cfg.project_slug, model=chosen, status="running")
+        return chosen
+
+    monkeypatch.setattr(manager, "stop_worker", AsyncMock(side_effect=stop_worker_override))
+    run_mock = AsyncMock(side_effect=run_worker_override)
+    monkeypatch.setattr(manager, "run_worker", run_mock)
+
+    callback = DummyCallback("project:switch_to:claudecode:sample")
+    _, fsm_state = _build_fsm_state()
+
+    async def _invoke():
+        await master.on_project_action(callback, fsm_state)
+
+    asyncio.run(_invoke())
+    run_mock.assert_awaited()
+    updated_state = manager.state_store.data["sample"]
+    assert updated_state.model == "claudecode"
+    assert updated_state.status == "running"
+    assert any("ClaudeCode" in (text or "") for text, _ in callback._answers)
+
+
+def test_switch_all_action_displays_model_options(repo: ProjectRepository, tmp_path: Path):
+    manager = _build_manager(repo, tmp_path)
+    master.MANAGER = manager
+    master.PROJECT_REPOSITORY = repo
+    callback = DummyCallback("project:switch_all:*")
+    _, fsm_state = _build_fsm_state()
+
+    async def _invoke():
+        await master.on_project_action(callback, fsm_state)
+
+    asyncio.run(_invoke())
+    assert callback._answers == [(None, False)]
+    assert callback.message._answers, "应展示全局模型选择键盘"
+    markup = callback.message._answers[-1][1]["reply_markup"]
+    button_texts = [btn.text for row in markup.inline_keyboard for btn in row]
+    assert any("Codex" in text for text in button_texts)
+    assert any("ClaudeCode" in text for text in button_texts)
+    assert any("取消" in text for text in button_texts)
+
+
+def test_switch_all_to_updates_all_models(repo: ProjectRepository, tmp_path: Path, monkeypatch):
+    second = ProjectRecord(
+        bot_name="OtherBot",
+        bot_token="222222:ABCDEFGHIJKLMNOPQRSTUVWXYZ111111",
+        project_slug="other",
+        default_model="codex",
+        workdir=str(tmp_path),
+        allowed_chat_id=None,
+        legacy_name=None,
+    )
+    repo.insert_project(second)
+    manager = _build_manager(repo, tmp_path)
+    master.MANAGER = manager
+    master.PROJECT_REPOSITORY = repo
+    manager.state_store.update("sample", model="codex", status="running")
+    manager.state_store.update("other", model="codex", status="stopped")
+
+    async def fake_stop_worker(cfg: master.ProjectConfig, *, update_state: bool = True) -> None:
+        manager.state_store.update(cfg.project_slug, status="stopped")
+
+    stop_mock = AsyncMock(side_effect=fake_stop_worker)
+    monkeypatch.setattr(manager, "stop_worker", stop_mock)
+
+    callback = DummyCallback("project:switch_all_to:claudecode:*")
+    _, fsm_state = _build_fsm_state()
+
+    async def _invoke():
+        await master.on_project_action(callback, fsm_state)
+
+    asyncio.run(_invoke())
+    assert stop_mock.await_count == len(manager.configs)
+    for slug, state in manager.state_store.data.items():
+        assert state.model == "claudecode"
+        assert state.status == "stopped"
+    summary_texts = [text for text, _ in callback.message._answers]
+    assert any("所有项目模型已切换为 ⚙️ ClaudeCode" in text for text in summary_texts)
