@@ -344,7 +344,7 @@ def test_task_history_callback(monkeypatch):
     assert "  - 标题：旧标题 -> 历史任务" in sent_text
     status_line_variants = ["- **更新状态** · 01-02 00:00", "- *更新状态* · 01-02 00:00"]
     assert any(fragment in sent_text for fragment in status_line_variants)
-    assert "  - 状态：🔍 调研 -> 🧪 测试" in sent_text
+    assert "  - 状态：🔍 调研中 -> 🧪 测试中" in sent_text
     assert reply_markup is not None
     assert reply_markup.inline_keyboard[-1][0].callback_data == f"{bot.TASK_HISTORY_BACK_CALLBACK}:{task.id}"
     assert callback.answers and callback.answers[-1][0] == "已展示历史记录"
